@@ -43,6 +43,8 @@ unsigned char *extract_zip(f_state *s, u_int64_t c_offset, unsigned char *founda
 	u_int64_t					bytes_to_search = 50 * KILOBYTE;
 	u_int64_t					file_size = 0;
 	int							oOffice = FALSE;
+	int							office2007 = FALSE;
+
 	char						comment[32];
 	localFH.genFlag=0;
 	localFH.compressed=0;
@@ -121,6 +123,28 @@ unsigned char *extract_zip(f_state *s, u_int64_t c_offset, unsigned char *founda
 					{
 					needle->suffix = "jar";
 					}
+				else if(strncmp((char *)foundat, "[Content_Types].xml",19)==0)
+					{
+						office2007=TRUE;
+					}
+				else if(strncmp((char *)foundat, "ppt/slides",10)==0 && office2007==TRUE)
+					{
+						needle->suffix = "pptx";
+					}
+				else if(strncmp((char *)foundat, "word/document.xml",17)==0 && office2007==TRUE)
+					{	
+						needle->suffix = "docx";
+					}
+				else if(strncmp((char *)foundat, "xl/workbook.xml",15)==0 && office2007==TRUE)
+					{	
+						needle->suffix = "xlsx";
+					}
+					
+					
+				else
+					{
+						printf("foundat=%s\n",foundat);
+					}	
 				}
 
 			foundat += localFH.compressed;
@@ -508,8 +532,9 @@ unsigned char *extract_cpp(f_state *s, u_int64_t c_offset, unsigned char *founda
 
 	if (foundat)
 		{
-		write_to_disk(s, needle, file_size, extractbuf, c_offset + f_offset + start + 1);
 		extractbuf = buf;
+		write_to_disk(s, needle, file_size, extractbuf, c_offset + f_offset + start + 1);
+		
 		return footer;
 
 		}
