@@ -254,6 +254,9 @@ char *__progname;
 #define EXE 26
 #define ELF 27
 #define REG 28
+#define DOCX 29
+#define XLSX 30
+#define PPTX 31
 
 #define KILOBYTE                  1024
 #define MEGABYTE                  1024 * KILOBYTE
