@@ -614,6 +614,54 @@ int set_search_def(f_state *s, char *ft, u_int64_t max_file_size)
 					 max_file_size,
 					 TRUE);
 
+		}
+	else if (strcmp(ft, "docx") == 0)
+		{
+		if (max_file_size == 0)
+			max_file_size = 10 * MEGABYTE;
+
+		init_builtin(s,
+					 DOCX,
+					 "docx",
+					 "\x50\x4B\x03\x04",
+					 "\x4b\x05\x06\x00",
+					 4,
+					 4,
+					 max_file_size,
+					 TRUE);
+
+		}
+	else if (strcmp(ft, "pptx") == 0)
+		{
+		if (max_file_size == 0)
+			max_file_size = 10 * MEGABYTE;
+
+		init_builtin(s,
+					 PPTX,
+					 "pptx",
+					 "\x50\x4B\x03\x04",
+					 "\x4b\x05\x06\x00",
+					 4,
+					 4,
+					 max_file_size,
+					 TRUE);
+
+		}
+	else if (strcmp(ft, "xlsx") == 0)
+		{
+		if (max_file_size == 0)
+			max_file_size = 10 * MEGABYTE;
+
+		init_builtin(s,
+					 XLSX,
+					 "xlsx",
+					 "\x50\x4B\x03\x04",
+					 "\x4b\x05\x06\x00",
+					 4,
+					 4,
+					 max_file_size,
+					 TRUE);
+
 		}
 	else if (strcmp(ft, "gzip") == 0 || strcmp(ft, "gz") == 0)
 		{
